summaryrefslogtreecommitdiff
path: root/core/fpdfdoc/cpdf_annot.h
diff options
context:
space:
mode:
Diffstat (limited to 'core/fpdfdoc/cpdf_annot.h')
-rw-r--r--core/fpdfdoc/cpdf_annot.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/core/fpdfdoc/cpdf_annot.h b/core/fpdfdoc/cpdf_annot.h
index df9f773521..d24e49777c 100644
--- a/core/fpdfdoc/cpdf_annot.h
+++ b/core/fpdfdoc/cpdf_annot.h
@@ -128,12 +128,12 @@ class CPDF_Annot {
// Get the AP in an annotation dict for a given appearance mode.
// If |eMode| is not Normal and there is not AP for that mode, falls back to
// the Normal AP.
-CPDF_Stream* FPDFDOC_GetAnnotAP(CPDF_Dictionary* pAnnotDict,
- CPDF_Annot::AppearanceMode eMode);
+CPDF_Stream* GetAnnotAP(CPDF_Dictionary* pAnnotDict,
+ CPDF_Annot::AppearanceMode eMode);
// Get the AP in an annotation dict for a given appearance mode.
-// No fallbacks to Normal like in FPDFDOC_GetAnnotAP.
-CPDF_Stream* FPDFDOC_GetAnnotAPNoFallback(CPDF_Dictionary* pAnnotDict,
- CPDF_Annot::AppearanceMode eMode);
+// No fallbacks to Normal like in GetAnnotAP.
+CPDF_Stream* GetAnnotAPNoFallback(CPDF_Dictionary* pAnnotDict,
+ CPDF_Annot::AppearanceMode eMode);
#endif // CORE_FPDFDOC_CPDF_ANNOT_H_